Follow these steps:

0. Get a number from the user if one wasn't already provided: <UserArguments>$ARGUMENTS</UserArguments>
1. Decide randomly to either double this number or return zero.
2. Write the result to a file called `resulting-number.txt` in the current directory.
